#####
#####  Hlavní skript pro shiny aplikaci
#####
#####  Arnošt Komárek
#####  https://msekce.karlin.mff.cuni.cz/~komarek
#####  komarek@karlin.mff.cuni.cz
#####
##### ==========================================
library("shiny")
library("colorspace")
library("xtable")
library("plotrix")

setwd("/home/komarek/teach/mff_2023/nmst547_AdvRko/Tutorial12/Rshiny/")
load("../Data/auta2004.RData")

### Běžná funkce na výpočet tabulky popisných statistik
### -----------------------------------------------------
tabPopStat <- function(Data, Var, gVar)
{
  tab <- data.frame(
    Drive  = c("Front", "Rear", "4x4"),                
    Mean   = tapply(Data[, Var], Data[, gVar], mean, na.rm = TRUE),
    SD     = tapply(Data[, Var], Data[, gVar], sd, na.rm = TRUE),
    Median = tapply(Data[, Var], Data[, gVar], median, na.rm = TRUE),
    Q1     = tapply(Data[, Var], Data[, gVar], quantile, prob = 0.25, na.rm = TRUE),
    Q3     = tapply(Data[, Var], Data[, gVar], quantile, prob = 0.75, na.rm = TRUE),
    n      = tapply(!is.na(Data[, Var]), Data[, gVar], sum),
    NAs    = tapply(is.na(Data[, Var]),  Data[, gVar], sum),
    stringsAsFactors = FALSE)  
  
  colnames(tab) <- c("Drive", "Mean", "Std. Dev.", "Median", "Q1", "Q3", "n", "Missing")
  # rownames(tab) <- c("Přední", "Zadní", "4x4")
  
  return(tab)    
}  


### Běžná funkce na vytvoření podmnožiny s typem nebo typy náhonu, které chceme
### ------------------------------------------------------------------------------
subData <- function(Data, Nahon)
{
  subData <- Data[1,]
  if ("1" %in% Nahon) subData <- rbind(subData, subset(Data, fnahon == "predni"))
  if ("2" %in% Nahon) subData <- rbind(subData, subset(Data, fnahon == "zadni"))
  if ("3" %in% Nahon) subData <- rbind(subData, subset(Data, fnahon == "4x4"))
  subData <- subData[-1,]    
  
  return(subData)
}  


shinyServer(function(input, output) 
{  
  ### Funkce na nakreslení scatterplotu
  ### -------------------------------------
  output$kresli_scatterplot <- renderPlot(
  {
  
    Data <- subData(Data = auta, Nahon = input$Nahon)
    
    XLIM <- range(auta[, input$xvar], na.rm = TRUE)
    YLIM <- range(auta[, input$yvar], na.rm = TRUE)
    BGC <- rainbow_hcl(3)
    COL <- c("red3", "blue", "darkgreen")
    names(BGC) <- names(COL) <- levels(auta[, "fnahon"])
    
    if (nrow(Data) == 0){
      plot(XLIM, YLIM, type = "n", xlab = input$xvar, ylab = input$yvar)
    }else{
      plot(Data[, input$xvar], Data[, input$yvar], xlab = input$xvar, ylab = input$yvar,
           pch = 23, col = COL[Data$fnahon], bg = BGC[Data$fnahon], xlim = XLIM, ylim = YLIM)
      if (input$chciLM){
        fit <- lm(Data[, input$yvar] ~ Data[, input$xvar])
        abline(fit, col = "orange", lwd = 2)
      }    
    }          
  }   
  )   ### konec renderPlot
 
  
  ### Funkce na nakreslení koláče podle druhu auta
  ### ---------------------------------------------
  output$kresli_kolac <- renderPlot(
  {
    Data <- subData(Data = auta, Nahon = input$Nahon)
    COL <- diverge_hcl(6)
    names(COL) <- levels(auta[, "fdruh"])
    
    if (nrow(Data) > 0){
      tDruh <- table(Data[, "fdruh"])
      Levs <- names(tDruh)[tDruh > 0]
      Cols <- COL[tDruh > 0]
      tDruh <- tDruh[tDruh > 0]      
      pie3D(tDruh, col = Cols, labels = Levs)
    }else{
      plot.new()
    }    
  }  
  )   ### konec renderPlot
  
  
  ### Funkce na výpočet a vytištění tabulky popisných statistik
  ### x-ové proměnné
  ### -------------------------------------------------
  output$pocitej_summaryx <- renderTable(
  {
     xtab <- tabPopStat(Data = auta, Var = input$xvar, gVar = "fnahon")
     return(xtab)       ### musí vracet něco, co jde poslat do xtable
  },
    ### Další argumenty funkce renderTable jsou poslány do xtable.
    # align = c("l", rep("r", 7)),
    digits  = c(0, rep(2, 5), 0, 0),
    label   = "tab:popisx"
  )  ### konec renderTable

  ### Funkce na výpočet a vytištění tabulky popisných statistik
  ### y-ové proměnné
  ### -------------------------------------------------
  output$pocitej_summaryy <- renderTable(
  { 
    ytab <- tabPopStat(Data = auta, Var = input$yvar, gVar = "fnahon")
    return(ytab)       ### musí vracet něco, co jde poslat do xtable
  },
    ### Další argumenty funkce renderTable jsou poslány do xtable.
    # align = c("l", rep("r", 7)),
    digits  = c(0, rep(2, 5), 0, 0),
    label   = "tab:popisy"
  )  ### konec renderTable

 
  ### Funkce na vytvoření summary(data)
  ### pro umístění ve výstupu
  ### -----------------------------------------------
  output$data_summary <- renderPrint(
  {
    Data <- subData(Data = auta, Nahon = input$Nahon)
    summary(Data)
  },
    width = 80
  )

  
  ### Funkce na zobrazení celých dat
  ### -------------------------------
  output$data_print <- renderDataTable(
  {
    Data <- subData(Data = auta, Nahon = input$Nahon)
    return(Data)
  })   ### konec renderDataTable

}
)  ### konec shinyServer
