#####
#####  User interface skript pro shiny aplikaci
#####
#####  Arnošt Komárek
#####  https://msekce.karlin.mff.cuni.cz/~komarek
#####  komarek@karlin.mff.cuni.cz
#####
##### ==========================================
library("shiny")

shinyUI(
 
  ### Rozmístění výstupů
  ### do "tabů",
  ### viz tabsetPanel
  
  fluidPage(
  
    ### Název aplikace (ve zvláštním panelu)
    ### -------------------------------------
    titlePanel("Data auta2004"),
    #headerPanel("Data auta2004"),

    
    ### Hlavní část
    ### -------------------------------------
    sidebarLayout(

      ### Udělátka
      ### ++++++++++++
      sidebarPanel(
        
        h4("Variables selection"),
        selectInput(inputId  = "xvar",
                    label    = strong("Variable for x-axis:"),
                    choices  = c("spotreba", "cena.prodej", "objem", "hmotnost", "delka", "sirka"),
                    selected = "hmotnost"),
        br(),
        
        selectInput(inputId  = "yvar",
                    label    = strong("Variable for y-axis:"),
                    choices  = c("spotreba", "cena.prodej", "objem", "hmotnost", "delka", "sirka"),
                    selected = "spotreba"),
        br(),

        h4("Drive selection"),
        checkboxGroupInput(inputId  = "Nahon",
                           label    = "",
                           choices  = list("Front" = 1, "Rear" = 2, "4x4" = 3),
                           selected = 1:3),
        br(), 
 
        h4("Draw a regression line?"),
        checkboxInput(inputId = "chciLM",
                      label   = strong("Yes"),
                      value   = TRUE),   
        br()
        
      ),  ### konec sidebarPanel
      
    
      ### Výstupy v "tabech"
      ### +++++++++++++++++++++++
      mainPanel(
        tabsetPanel(
          
           ### Scatterplot
           ### +++++++++++++
           tabPanel("Scatterplot", h3("Scatterplot (x, y)"),
                                   plotOutput(outputId = "kresli_scatterplot",
                                              height   = "500px")),

           ### Koláč
           ### +++++++++++++
           tabPanel("Pie", h3("Pie (car sort)"),
                    plotOutput(outputId = "kresli_kolac",
                               height   = "500px")),
           
           
           ### Popisné statistiky
           ### +++++++++++++++++++++
           tabPanel("Tables",  h3("Descriptive statistics for x"),
                               tableOutput(outputId = "pocitej_summaryx"),
                               br(),
                               h3("Descriptive statistics for y"),
                               tableOutput(outputId = "pocitej_summaryy")),
           
           ### Popisné statistiky celých dat
           ### obyčejný výstup z R summary
           ### +++++++++++++++++++++++++++++++
           tabPanel("Summary", h3("Summary"),
                              verbatimTextOutput(outputId = "data_summary")),
           
           ### Data
           ### +++++++++++++++++++++++++++++++
           tabPanel("Data", h3("Data"),
                            dataTableOutput(outputId = "data_print"))
          
        )     ### konec tabsetPanel
      )     ### konec mainPanel
    
    )     ### konec sidebarLayout    
  )     ### konec fluidPage  
)
